# GisPandas针对栅格数据进行统计的python包
GisPandas是一个为栅格、矢量数据处理、分析以及可视化而开发的Python包。GisPandas为常见栅格矢量数据提供了快速而简洁的gis操作方法，代码简洁、高效、灵活、易用，可以用简洁的代码实现复杂的数据任务。
# 主要功能
目前，GisPandas主要提供以下方法：
1.栅格数据进行阿尔伯斯等面积投影，根据矢量区划计算面积并导出json。
2.种植结构变化。
3.gee栅格数据镶嵌并压缩。
4.矢量数据写入四至、置信等属性，矢量简化，文本矢量化等。
5.栅格数据像素对齐、裁剪、重采样、投影、插值、切片、格式转换等。
# 安装
pip install gispandas
# 相关链接
本项目的github页面：https://github.com/mxhou/gispandas

有bug请在这个页面提交：https://github.com/mxhou/gispandas/issues